==> react-molecule-rating-1.2.0.tgz: package/lib/components/Star.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { IconStarFilled, IconStarHalfFilled, IconStarOutline } from '../Icons';
var BASE_CLASS = "sui-MoleculeRating-Star";
var DEFAULTS = {
  value: 0,
  fullValue: 1,
  halfValue: 0.5,
  IconStarFilled: IconStarFilled,
  IconStarHalfFilled: IconStarHalfFilled,
  IconStarEmpty: IconStarOutline
};

var MoleculeRatingStar = function MoleculeRatingStar(_ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? DEFAULTS.value : _ref$value,
      _ref$fullValue = _ref.fullValue,
      fullValue = _ref$fullValue === void 0 ? DEFAULTS.fullValue : _ref$fullValue,
      _ref$halfValue = _ref.halfValue,
      halfValue = _ref$halfValue === void 0 ? DEFAULTS.halfValue : _ref$halfValue,
      index = _ref.index,
      _ref$IconStarEmpty = _ref.IconStarEmpty,
      IconStarEmpty = _ref$IconStarEmpty === void 0 ? DEFAULTS.IconStarEmpty : _ref$IconStarEmpty,
      _ref$IconStarFilled = _ref.IconStarFilled,
      IconStarFilled = _ref$IconStarFilled === void 0 ? DEFAULTS.IconStarFilled : _ref$IconStarFilled,
      _ref$IconStarHalfFill = _ref.IconStarHalfFilled,
      IconStarHalfFilled = _ref$IconStarHalfFill === void 0 ? DEFAULTS.IconStarHalfFilled : _ref$IconStarHalfFill;
  var StarMode = IconStarEmpty;
  if (value >= index + fullValue) StarMode = IconStarFilled;else if (value >= index + halfValue) StarMode = IconStarHalfFilled;
  return React.createElement("div", {
    className: BASE_CLASS
  }, React.createElement(StarMode, null));
};

MoleculeRatingStar.displayName = 'MoleculeRatingStar';
export default MoleculeRatingStar;

==> react-molecule-rating-1.8.0.tgz: package/lib/components/Star.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { IconStarFilled, IconStarHalfFilled, IconStarOutline } from '../Icons';
var BASE_CLASS = "sui-MoleculeRating-Star";
var DEFAULTS = {
  value: 0,
  fullValue: 1,
  halfValue: 0.5,
  IconStarFilled: IconStarFilled,
  IconStarHalfFilled: IconStarHalfFilled,
  IconStarEmpty: IconStarOutline
};

var MoleculeRatingStar = function MoleculeRatingStar(_ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? DEFAULTS.value : _ref$value,
      _ref$fullValue = _ref.fullValue,
      fullValue = _ref$fullValue === void 0 ? DEFAULTS.fullValue : _ref$fullValue,
      _ref$halfValue = _ref.halfValue,
      halfValue = _ref$halfValue === void 0 ? DEFAULTS.halfValue : _ref$halfValue,
      index = _ref.index,
      _ref$IconStarEmpty = _ref.IconStarEmpty,
      IconStarEmpty = _ref$IconStarEmpty === void 0 ? DEFAULTS.IconStarEmpty : _ref$IconStarEmpty,
      _ref$IconStarFilled = _ref.IconStarFilled,
      IconStarFilled = _ref$IconStarFilled === void 0 ? DEFAULTS.IconStarFilled : _ref$IconStarFilled,
      _ref$IconStarHalfFill = _ref.IconStarHalfFilled,
      IconStarHalfFilled = _ref$IconStarHalfFill === void 0 ? DEFAULTS.IconStarHalfFilled : _ref$IconStarHalfFill;
  var StarMode = IconStarEmpty;
  if (value >= index + fullValue) StarMode = IconStarFilled;else if (value >= index + halfValue) StarMode = IconStarHalfFilled;
  return /*#__PURE__*/React.createElement("div", {
    className: BASE_CLASS
  }, /*#__PURE__*/React.createElement(StarMode, null));
};

MoleculeRatingStar.displayName = 'MoleculeRatingStar';
export default MoleculeRatingStar;
